@@ -5,7 +5,7 @@ use PDF::Reuse;
 use strict;
 use warnings;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 my ($str, $xsize, $ysize, $height, $sPtn, @sizes, $length, $value, %default);
 
@@ -21,7 +21,8 @@ sub init
                   drawbackground  => 1,
                   text            => 'yes',
                   prolong         => 0,
-                  hide_asterisk   => 0);
+                  hide_asterisk   => 0,
+                  mode            => 'Type3');
    $str    = '';
    $xsize  = 1;
    $ysize  = 1;
@@ -70,7 +71,12 @@ sub general2
     
    @sizes = prFontSize(12);
 
-   prBar( 10, $step, $sPtn);
+   if ($default{'mode'} eq 'Type3')
+   {  prBar( 10, $step, $sPtn);
+   } 
+   else  # graphic mode 
+   {  $str = Bar( 10, $step, $sPtn);
+   }
 
    $prolong--;
    
@@ -85,9 +91,19 @@ sub general2
           {   $step += (12 * $prolong);
               $prolong = 0;
           }
-          prBar( 10, $step, $sPtn);
+          if ($default{'mode'} eq 'Type3')
+          {  prBar( 10, $step, $sPtn);
+          } 
+          else   # graphic mode
+          {  $str .= Bar( 10, $step, $sPtn);
+          }
        }
-    }       
+    }
+    # print the graphic mode bars
+    if ($default{'mode'} ne 'Type3')
+    {   $str .= "B\n";    
+        prAdd($str);
+    }  
 
 }
 
@@ -111,8 +127,24 @@ sub standardEnd
    general3();
    
    1;
+}
 
+sub Bar
+{  my ($x, $y, $pattern) = @_;
+   my $yEnd = $y + 20;
+   my $yG   = $y - 3;
 
+   my $string = "0.92 w\n 0 0 0 RG\n";
+   for (split(//, $pattern))
+   {   if ($_ eq '1')
+       {  $string .= "$x $yEnd m\n $x $y l\n";
+       }
+       elsif($_ eq 'G')
+       {  $string .= "$x $yEnd m\n $x $yG l\n";
+       }  
+       $x += 0.91;
+   }
+   return $string;
 }
 
 sub Code128
@@ -609,6 +641,10 @@ high (the guard bars a few pixels longer) and the box/background is 38 pixels hi
 and something like 20 pixels wider than the barcodes. The text under the bars are
 10 pixels high.
 
+The barcodes are generated using a Type3 font by default. Ghostscript and xpdf 
+don'thave support for Type3 fonts. If you want to target engines that don't 
+handle Type3 fonts properly, see the "mode" parameter. 
+
 =head1 FUNCTIONS
 
 All functions are called in a similar way. Just replace 'ITF' in the example
@@ -787,6 +823,16 @@ Choose another RGB-combination if you want another color.
 
 A degree to rotate the barcode image counter-clockwise
 
+=head2 mode
+
+Defaults to 'Type3', which means that a Type3 font will be embedded in the PDF
+document and then used to print the barcodes. Type3 fonts are not supported by
+some PDF interpreters, namely Ghostscript and xpdf. 
+
+Set the mode to 'graphic' (currently, any string that doesn't match 'Type3' will
+do, but you should not count on this) to get graphic bars that work on all 
+engines.
+
 =head1 EXAMPLE
 
   use PDF::Reuse;
@@ -824,6 +870,16 @@ A degree to rotate the barcode image counter-clockwise
                               value   => '012345678901',
                               size    => 1.5);
 
+  ####################################################################
+  # "Graphic" barcodes. (The others on this page use a special font)
+  ####################################################################
+
+  PDF::Reuse::Barcode::EAN13 (x       => 250,
+                              y       => 600,
+                              value   => '012345678901',
+                              size    => 1.5,
+                              mode    => 'graphic');
+
   ######################################################
   # A barcode image magnified a little along the y-axis
   ######################################################
@@ -901,6 +957,12 @@ These modules are used for calculation of the barcode pattern
 
 Lars Lundberg, elkelund@worldonline.se
 
+=head1 THANKS TO
+
+Everyone who has helped me with corrections and ideas, Martin Langhoff among others.
+And of course credits to Kawai Takanori and William R. Ward who have written the
+modules for calculating the barcode patterns.
+
 =head1 COPYRIGHT
 
 Copyright (C) 2003 - 2004 Lars Lundberg, Solidez HB. All rights reserved.
